Package: putior
Title: "Register In- and Outputs for Workflow Visualization"
Version: 0.1.0
Authors@R: 
    person("Philipp", "Thoss", , "ph.thoss@gmx.de", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-4672-2792"))
Author: Philipp Thoss [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-4672-2792>)
Maintainer: Philipp Thoss <ph.thoss@gmx.de>
Description: Provides tools for extracting and processing structured annotations from 'R' 
    and 'Python' source files to facilitate workflow visualization. The package scans 
    source files for special 'PUT' annotations that define nodes, connections, and 
    metadata within a data processing workflow. These annotations can then be used 
    to generate visual representations of data flows and processing steps across 
    polyglot software environments. Builds on concepts from literate programming 
    Knuth (1984) <doi:10.1093/comjnl/27.2.97> and utilizes directed acyclic graph (DAG) 
    theory for workflow representation Foraita, Spallek, and Zeeb (2014) 
    <doi:10.1007/978-0-387-09834-0_65>. Diagram generation powered by 'Mermaid' 
    Sveidqvist (2014) <https://mermaid.js.org/>.
Language: en-US
License: MIT + file LICENSE
URL: https://pjt222.github.io/putior/, https://github.com/pjt222/putior
BugReports: https://github.com/pjt222/putior/issues
Depends: R (>= 3.5.0)
Imports: tools
Suggests: testthat (>= 3.0.0), knitr, rmarkdown, clipr, uuid, pkgdown
Encoding: UTF-8
RoxygenNote: 7.3.2
Config/testthat/edition: 3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-06-18 10:49:27 UTC; phtho
Repository: CRAN
Date/Publication: 2025-06-19 14:50:02 UTC
Built: R 4.6.0; ; 2026-04-27 00:44:13 UTC; unix
